class ActionButtonsMixin:
    class Media:
        js = [
            'admin_action_buttons/admin_action_buttons.js',
        ]
        css = {
            'all': [
                'admin_action_buttons/admin_action_buttons.css',
            ],
        }
